import DataProviderCategory

#Default Categories for the DataProviders
CATEGORY_FILES = DataProviderCategory.DataProviderCategory("Files and Folders", "computer")
CATEGORY_NOTES = DataProviderCategory.DataProviderCategory("Notes", "tomboy")
CATEGORY_PHOTOS = DataProviderCategory.DataProviderCategory("Photos", "image-x-generic")
CATEGORY_OFFICE = DataProviderCategory.DataProviderCategory("Office", "applications-office")
CATEGORY_SETTINGS = DataProviderCategory.DataProviderCategory("Settings", "applications-system")
CATEGORY_MISC = DataProviderCategory.DataProviderCategory("Miscellaneous", "applications-accessories")
CATEGORY_MEDIA = DataProviderCategory.DataProviderCategory("Media", "applications-multimedia")
CATEGORY_TEST = DataProviderCategory.DataProviderCategory("Test")
